measuretools.Measure
====================

.. inheritance-diagram:: abjad.tools.measuretools.Measure.Measure.Measure
   :private-bases:

.. autoclass:: abjad.tools.measuretools.Measure.Measure.Measure

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.contents_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.duration_in_seconds

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_binary

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_full

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_nonbinary

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_overfull

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_underfull

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.leaves

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.measure_number

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.multiplier

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.music

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.preprolated_duration

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.measuretools.Measure.Measure.Measure.is_parallel

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Methods
-------

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.append

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.extend

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.index

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.insert

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.pop

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.remove

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__add__

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__contains__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__delitem__

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__getitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__iadd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__imul__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__len__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__radd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__repr__

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__setitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.Measure.Measure.Measure.__str__
